@@ -115,8 +115,7 @@ class SSOAdminClient(BaseClient):
         CustomerManagedPolicyReference: CustomerManagedPolicyReferenceTypeDef
     ) -> Dict[str, Any]:
         """
-        Attaches the specified IAM customer managed policy to the specified
-        PermissionSet .
+        Attaches the specified customer managed policy to the specified  PermissionSet .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.attach_customer_managed_policy_reference_to_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_customer_managed_policy_reference_to_permission_set)
@@ -126,7 +125,7 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        Attaches an Amazon Web Services managed IAM policy ARN to a permission set.
+        Attaches an Amazon Web Services managed policy ARN to a permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#attach_managed_policy_to_permission_set)
@@ -191,7 +190,7 @@ class SSOAdminClient(BaseClient):
         Tags: Sequence[TagTypeDef] = ...
     ) -> CreatePermissionSetResponseTypeDef:
         """
-        Creates a permission set within a specified SSO instance.
+        Creates a permission set within a specified Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#create_permission_set)
@@ -315,8 +314,8 @@ class SSOAdminClient(BaseClient):
         CustomerManagedPolicyReference: CustomerManagedPolicyReferenceTypeDef
     ) -> Dict[str, Any]:
         """
-        Detaches the specified IAM customer managed policy from the specified
-        PermissionSet .
+        Detaches the specified customer managed policy from the specified  PermissionSet
+        .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.detach_customer_managed_policy_reference_from_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_customer_managed_policy_reference_from_permission_set)
@@ -326,8 +325,8 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        Detaches the attached Amazon Web Services managed IAM policy ARN from the
-        specified permission set.
+        Detaches the attached Amazon Web Services managed policy ARN from the specified
+        permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#detach_managed_policy_from_permission_set)
@@ -377,7 +376,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListAccountAssignmentCreationStatusResponseTypeDef:
         """
         Lists the status of the Amazon Web Services account assignment creation requests
-        for a specified SSO instance.
+        for a specified Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_creation_status)
@@ -393,7 +392,7 @@ class SSOAdminClient(BaseClient):
     ) -> ListAccountAssignmentDeletionStatusResponseTypeDef:
         """
         Lists the status of the Amazon Web Services account assignment deletion requests
-        for a specified SSO instance.
+        for a specified Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_account_assignment_deletion_status)
@@ -442,7 +441,7 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListCustomerManagedPolicyReferencesInPermissionSetResponseTypeDef:
         """
-        Lists all IAM customer managed policies attached to a specified  PermissionSet .
+        Lists all customer managed policies attached to a specified  PermissionSet .
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_customer_managed_policy_references_in_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_customer_managed_policy_references_in_permission_set)
@@ -452,7 +451,7 @@ class SSOAdminClient(BaseClient):
         self, *, MaxResults: int = ..., NextToken: str = ...
     ) -> ListInstancesResponseTypeDef:
         """
-        Lists the SSO instances that the caller has access to.
+        Lists the Amazon Web Services SSO instances that the caller has access to.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_instances)
@@ -467,7 +466,7 @@ class SSOAdminClient(BaseClient):
         NextToken: str = ...
     ) -> ListManagedPoliciesInPermissionSetResponseTypeDef:
         """
-        Lists the Amazon Web Services managed IAM policy that is attached to a specified
+        Lists the Amazon Web Services managed policy that is attached to a specified
         permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
@@ -483,8 +482,8 @@ class SSOAdminClient(BaseClient):
         Filter: OperationStatusFilterTypeDef = ...
     ) -> ListPermissionSetProvisioningStatusResponseTypeDef:
         """
-        Lists the status of the permission set provisioning requests for a specified SSO
-        instance.
+        Lists the status of the permission set provisioning requests for a specified
+        Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_set_provisioning_status)
@@ -494,7 +493,7 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, NextToken: str = ..., MaxResults: int = ...
     ) -> ListPermissionSetsResponseTypeDef:
         """
-        Lists the  PermissionSet s in an SSO instance.
+        Lists the  PermissionSet s in an Amazon Web Services SSO instance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#list_permission_sets)
@@ -547,7 +546,7 @@ class SSOAdminClient(BaseClient):
         self, *, InstanceArn: str, PermissionSetArn: str, InlinePolicy: str
     ) -> Dict[str, Any]:
         """
-        Attaches an IAM inline policy to a permission set.
+        Attaches an inline policy to a permission set.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client/#put_inline_policy_to_permission_set)
@@ -561,7 +560,7 @@ class SSOAdminClient(BaseClient):
         PermissionsBoundary: PermissionsBoundaryTypeDef
     ) -> Dict[str, Any]:
         """
-        Attaches an Amazon Web Services managed or customer managed IAM policy to the
+        Attaches an Amazon Web Services managed or customer managed policy to the
         specified  PermissionSet as a permissions boundary.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Client.put_permissions_boundary_to_permission_set)
