@@ -14,6 +14,7 @@ Usage::
         ListAccountAssignmentDeletionStatusPaginator,
         ListAccountAssignmentsPaginator,
         ListAccountsForProvisionedPermissionSetPaginator,
+        ListCustomerManagedPolicyReferencesInPermissionSetPaginator,
         ListInstancesPaginator,
         ListManagedPoliciesInPermissionSetPaginator,
         ListPermissionSetProvisioningStatusPaginator,
@@ -29,6 +30,7 @@ Usage::
     list_account_assignment_deletion_status_paginator: ListAccountAssignmentDeletionStatusPaginator = client.get_paginator("list_account_assignment_deletion_status")
     list_account_assignments_paginator: ListAccountAssignmentsPaginator = client.get_paginator("list_account_assignments")
     list_accounts_for_provisioned_permission_set_paginator: ListAccountsForProvisionedPermissionSetPaginator = client.get_paginator("list_accounts_for_provisioned_permission_set")
+    list_customer_managed_policy_references_in_permission_set_paginator: ListCustomerManagedPolicyReferencesInPermissionSetPaginator = client.get_paginator("list_customer_managed_policy_references_in_permission_set")
     list_instances_paginator: ListInstancesPaginator = client.get_paginator("list_instances")
     list_managed_policies_in_permission_set_paginator: ListManagedPoliciesInPermissionSetPaginator = client.get_paginator("list_managed_policies_in_permission_set")
     list_permission_set_provisioning_status_paginator: ListPermissionSetProvisioningStatusPaginator = client.get_paginator("list_permission_set_provisioning_status")
@@ -39,8 +41,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .literals import ProvisioningStatusType
 from .type_defs import (
@@ -48,6 +49,7 @@ from .type_defs import (
     ListAccountAssignmentDeletionStatusResponseTypeDef,
     ListAccountAssignmentsResponseTypeDef,
     ListAccountsForProvisionedPermissionSetResponseTypeDef,
+    ListCustomerManagedPolicyReferencesInPermissionSetResponseTypeDef,
     ListInstancesResponseTypeDef,
     ListManagedPoliciesInPermissionSetResponseTypeDef,
     ListPermissionSetProvisioningStatusResponseTypeDef,
@@ -63,6 +65,7 @@ __all__ = (
     "ListAccountAssignmentDeletionStatusPaginator",
     "ListAccountAssignmentsPaginator",
     "ListAccountsForProvisionedPermissionSetPaginator",
+    "ListCustomerManagedPolicyReferencesInPermissionSetPaginator",
     "ListInstancesPaginator",
     "ListManagedPoliciesInPermissionSetPaginator",
     "ListPermissionSetProvisioningStatusPaginator",
@@ -82,7 +85,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListAccountAssignmentCreationStatusPaginator(Boto3Paginator):
+class ListAccountAssignmentCreationStatusPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listaccountassignmentcreationstatuspaginator)
@@ -92,8 +95,8 @@ class ListAccountAssignmentCreationStatusPaginator(Boto3Paginator):
         self,
         *,
         InstanceArn: str,
-        Filter: "OperationStatusFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: OperationStatusFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccountAssignmentCreationStatusResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus.paginate)
@@ -101,7 +104,7 @@ class ListAccountAssignmentCreationStatusPaginator(Boto3Paginator):
         """
 
 
-class ListAccountAssignmentDeletionStatusPaginator(Boto3Paginator):
+class ListAccountAssignmentDeletionStatusPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listaccountassignmentdeletionstatuspaginator)
@@ -111,8 +114,8 @@ class ListAccountAssignmentDeletionStatusPaginator(Boto3Paginator):
         self,
         *,
         InstanceArn: str,
-        Filter: "OperationStatusFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: OperationStatusFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccountAssignmentDeletionStatusResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus.paginate)
@@ -120,7 +123,7 @@ class ListAccountAssignmentDeletionStatusPaginator(Boto3Paginator):
         """
 
 
-class ListAccountAssignmentsPaginator(Boto3Paginator):
+class ListAccountAssignmentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listaccountassignmentspaginator)
@@ -132,7 +135,7 @@ class ListAccountAssignmentsPaginator(Boto3Paginator):
         InstanceArn: str,
         AccountId: str,
         PermissionSetArn: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccountAssignmentsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments.paginate)
@@ -140,7 +143,7 @@ class ListAccountAssignmentsPaginator(Boto3Paginator):
         """
 
 
-class ListAccountsForProvisionedPermissionSetPaginator(Boto3Paginator):
+class ListAccountsForProvisionedPermissionSetPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listaccountsforprovisionedpermissionsetpaginator)
@@ -152,7 +155,7 @@ class ListAccountsForProvisionedPermissionSetPaginator(Boto3Paginator):
         InstanceArn: str,
         PermissionSetArn: str,
         ProvisioningStatus: ProvisioningStatusType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAccountsForProvisionedPermissionSetResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet.paginate)
@@ -160,14 +163,33 @@ class ListAccountsForProvisionedPermissionSetPaginator(Boto3Paginator):
         """
 
 
-class ListInstancesPaginator(Boto3Paginator):
+class ListCustomerManagedPolicyReferencesInPermissionSetPaginator(Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListCustomerManagedPolicyReferencesInPermissionSet)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listcustomermanagedpolicyreferencesinpermissionsetpaginator)
+    """
+
+    def paginate(
+        self,
+        *,
+        InstanceArn: str,
+        PermissionSetArn: str,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListCustomerManagedPolicyReferencesInPermissionSetResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListCustomerManagedPolicyReferencesInPermissionSet.paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listcustomermanagedpolicyreferencesinpermissionsetpaginator)
+        """
+
+
+class ListInstancesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listinstancespaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListInstancesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances.paginate)
@@ -175,7 +197,7 @@ class ListInstancesPaginator(Boto3Paginator):
         """
 
 
-class ListManagedPoliciesInPermissionSetPaginator(Boto3Paginator):
+class ListManagedPoliciesInPermissionSetPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listmanagedpoliciesinpermissionsetpaginator)
@@ -186,7 +208,7 @@ class ListManagedPoliciesInPermissionSetPaginator(Boto3Paginator):
         *,
         InstanceArn: str,
         PermissionSetArn: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListManagedPoliciesInPermissionSetResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet.paginate)
@@ -194,7 +216,7 @@ class ListManagedPoliciesInPermissionSetPaginator(Boto3Paginator):
         """
 
 
-class ListPermissionSetProvisioningStatusPaginator(Boto3Paginator):
+class ListPermissionSetProvisioningStatusPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listpermissionsetprovisioningstatuspaginator)
@@ -204,8 +226,8 @@ class ListPermissionSetProvisioningStatusPaginator(Boto3Paginator):
         self,
         *,
         InstanceArn: str,
-        Filter: "OperationStatusFilterTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filter: OperationStatusFilterTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPermissionSetProvisioningStatusResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus.paginate)
@@ -213,14 +235,14 @@ class ListPermissionSetProvisioningStatusPaginator(Boto3Paginator):
         """
 
 
-class ListPermissionSetsPaginator(Boto3Paginator):
+class ListPermissionSetsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listpermissionsetspaginator)
     """
 
     def paginate(
-        self, *, InstanceArn: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, InstanceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPermissionSetsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets.paginate)
@@ -228,7 +250,7 @@ class ListPermissionSetsPaginator(Boto3Paginator):
         """
 
 
-class ListPermissionSetsProvisionedToAccountPaginator(Boto3Paginator):
+class ListPermissionSetsProvisionedToAccountPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listpermissionsetsprovisionedtoaccountpaginator)
@@ -240,7 +262,7 @@ class ListPermissionSetsProvisionedToAccountPaginator(Boto3Paginator):
         InstanceArn: str,
         AccountId: str,
         ProvisioningStatus: ProvisioningStatusType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListPermissionSetsProvisionedToAccountResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount.paginate)
@@ -248,18 +270,14 @@ class ListPermissionSetsProvisionedToAccountPaginator(Boto3Paginator):
         """
 
 
-class ListTagsForResourcePaginator(Boto3Paginator):
+class ListTagsForResourcePaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators/#listtagsforresourcepaginator)
     """
 
     def paginate(
-        self,
-        *,
-        InstanceArn: str,
-        ResourceArn: str,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, InstanceArn: str, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTagsForResourceResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource.paginate)
